import { Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { DomSanitizer, SafeResourceUrl } from '@angular/platform-browser';


//detail跳转
import { Router, ActivatedRoute } from '@angular/router';

interface Home {
  name: string;
  description: string;
  imageUrl: string;
}

@Component({
  selector: 'app-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.scss']  // 添加样式文件
})
export class HomeComponent {
  homes: Home[] = [
    {
      name: 'Digital Collectible 1',
      description: 'This is the first digital collectible.',
      imageUrl: 'https://example.com/digital-collectible1.jpg'
    },
    {
      name: 'Digital Collectible 2',
      description: 'This is the second digital collectible.',
      imageUrl: 'https://example.com/digital-collectible-2.jpg'
    },
    {
      name: 'Digital Collectible 3',
      description: 'This is the third digital collectible.',
      imageUrl: 'https://example.com/digital-collectible-3.jpg'
    },
    // 添加更多的数字藏品数据...
  ];
  itemList: Home[] = []; // 初始化物品列表为空
  sanitizer: DomSanitizer;

  constructor(private _sanitizer: DomSanitizer, private router: Router, private route: ActivatedRoute) {
    this.sanitizer = _sanitizer as DomSanitizer;
    this.showItemList('推荐'); // 默认显示推荐物品列表
  }

  getSafeImageUrl(url: string): SafeResourceUrl {
    return this.sanitizer.bypassSecurityTrustResourceUrl(url);
  }

  showItemList(type: string) {
    if (type === '热门') {
      // 通过你的自定义逻辑获取热门物品列表
      this.itemList = this.homes.filter(home => {
        // 这里可以根据需要筛选出对应类型的物品
        return home.name === 'Digital Collectible 1' || home.name === 'Digital Collectible 2';
      });
    } else if (type === '推荐') {
      // 通过你的自定义逻辑获取推荐物品列表
      this.itemList = this.homes.filter(home => {
        // 这里可以根据需要筛选出对应类型的物品
        return home.name === 'Digital Collectible 1' || home.name === 'Digital Collectible 3';
      });
    } else if (type === '活动') {
      // 通过你的自定义逻辑获取活动物品列表
      this.itemList = this.homes.filter(home => {
        // 这里可以根据需要筛选出对应类型的物品
        return home.name === 'Digital Collectible 2' || home.name === 'Digital Collectible 3';
      });
    }
  }
  goToItemDetail(name: string) {
    // 实现你的方法逻辑
    this.router.navigate(['../page-item-detail', name], { relativeTo: this.route });
  }
}

@NgModule({
  imports: [CommonModule],
  declarations: [HomeComponent],
  exports: [HomeComponent]
})
export class HomeModule { }